@@ -17,12 +17,10 @@ from invenio_accounts.utils import register_user
 from invenio_db import db
 from invenio_db.utils import rebuild_encrypted_properties
 from itsdangerous import TimedJSONWebSignatureSerializer
-from sqlalchemy.exc import IntegrityError
 from uritools import uricompose, urisplit
 from werkzeug.local import LocalProxy
 from werkzeug.utils import import_string
 
-from .errors import AlreadyLinkedError
 from .models import RemoteAccount, RemoteToken, UserIdentity
 
 _security = LocalProxy(lambda: current_app.extensions['security'])
@@ -71,10 +69,10 @@ def oauth_get_user(client_id, account_info=None, access_token=None):
     if account_info:
         external_id = _get_external_id(account_info)
         if external_id:
-            user_identity = UserIdentity.query.filter_by(
-                id=external_id['id'], method=external_id['method']).first()
-            if user_identity:
-                return user_identity.user
+            user = UserIdentity.get_user(
+                external_id['method'], external_id['id'])
+            if user:
+                return user
         email = account_info.get('user', {}).get('email')
         if email:
             return User.query.filter_by(email=email).one_or_none()
@@ -93,7 +91,7 @@ def oauth_authenticate(client_id, user, require_existing_link=False):
     # Authenticate via the access token (access token used to get user_id)
     if not requires_confirmation(user):
         after_this_request(_commit)
-        if login_user(user, remember=False):
+        if login_user(user):
             if require_existing_link:
                 account = RemoteAccount.get(user.id, client_id)
                 if account is None:
@@ -156,6 +154,20 @@ def remove_csrf_tokens(user_data):
             remove_csrf_tokens(value)
 
 
+def remove_none_values(user_data):
+    """Remove None values from the user data."""
+    del_keys = []
+    for key, value in list(user_data.items()):
+        if isinstance(value, dict):
+            remove_none_values(value)
+            if value == {}:
+                del_keys.append(key)
+        if value is None:
+            del_keys.append(key)
+    for key in del_keys:
+        del user_data[key]
+
+
 def oauth_register(form, user_info=None, precedence_mask=None):
     """Register user if possible.
 
@@ -164,15 +176,21 @@ def oauth_register(form, user_info=None, precedence_mask=None):
     :returns: A :class:`invenio_accounts.models.User` instance.
     """
     if form.validate():
-        data = form.to_dict()
+        form_data = form.data
 
         # let relevant information from the OAuth service's user info
         # have precedence over the values specified by the user
         if user_info:
             default_mask = {"email": True}
+            # act on form data so the `profile` is updated correctly
             filter_user_info(user_info, precedence_mask or default_mask)
-            patch_dictionary(data, user_info)
+            patch_dictionary(form_data, user_info)
 
+        # re-populate the form after appyling the precedence mask and
+        # convert the form data to user model's data
+        data = fill_form(form, form_data).to_dict()
+        # see https://github.com/inveniosoftware/invenio-oauthclient/issues/275
+        remove_none_values(data)
         # remove the CSRF tokens to avoid unexpected keyword arguments
         remove_csrf_tokens(data)
         user = register_user(**data)
@@ -189,15 +207,8 @@ def oauth_link_external_id(user, external_id=None):
     :raises invenio_oauthclient.errors.AlreadyLinkedError: Raised if already
         exists a link.
     """
-    try:
-        with db.session.begin_nested():
-            db.session.add(UserIdentity(
-                id=external_id['id'],
-                method=external_id['method'],
-                id_user=user.id
-            ))
-    except IntegrityError:
-        raise AlreadyLinkedError(user, external_id)
+    # Backward compatibility. Use UserIdentity directly instead of this method.
+    UserIdentity.create(user, external_id['method'], external_id['id'])
 
 
 def oauth_unlink_external_id(external_id):
@@ -205,9 +216,8 @@ def oauth_unlink_external_id(external_id):
 
     :param external_id: The external id associated with the user.
     """
-    with db.session.begin_nested():
-        UserIdentity.query.filter_by(id=external_id['id'],
-                                     method=external_id['method']).delete()
+    UserIdentity.delete_by_external_id(
+        external_id['method'], external_id['id'])
 
 
 def get_safe_redirect_target(arg='next'):
