@@ -115,6 +115,10 @@ def base_app(request):
             consumer_key='globus_key_changeme',
             consumer_secret='globus_secret_changeme',
         ),
+        TEST_APP_CREDENTIALS=dict(
+            consumer_key='test_key_changeme',
+            consumer_secret='test_secret_changeme',
+        ),
         OAUTHCLIENT_KEYCLOAK_USER_INFO_URL=helper.user_info_url,
         OAUTHCLIENT_KEYCLOAK_REALM_URL=helper.realm_url,
         OAUTHCLIENT_KEYCLOAK_VERIFY_AUD=True,
@@ -128,6 +132,14 @@ def base_app(request):
         EMAIL_BACKEND='flask_email.backends.locmem.Mail',
         SQLALCHEMY_DATABASE_URI=os.getenv('SQLALCHEMY_DATABASE_URI',
                                           'sqlite://'),
+        # Alembic runs all migrations in a single transaction, and in
+        # oauthclient the useridentity table can be in state where it's created
+        # and then deleted in the same transaction. On PostgreSQL which
+        # supports transactional DDL therefore fails if we don't run each
+        # migration in its own migration.
+        ALEMBIC_CONTEXT={
+            'transaction_per_migration': True,
+        },
         SERVER_NAME='localhost',
         DEBUG=False,
         SECRET_KEY='TEST',
@@ -135,6 +147,7 @@ def base_app(request):
         SQLALCHEMY_TRACK_MODIFICATIONS=False,
         SECURITY_PASSWORD_HASH='plaintext',
         SECURITY_PASSWORD_SCHEMES=['plaintext'],
+        SECURITY_PASSWORD_SINGLE_HASH=None,
         APP_ALLOWED_HOSTS=['localhost'],
         APP_THEME=['semantic-ui'],
         THEME_ICONS={
@@ -284,6 +297,7 @@ def params():
             authorize_url='https://foo.bar/oauth/authorize',
             consumer_key=x,
             consumer_secret='testsecret',
+            app_key="TEST_APP_CREDENTIALS"
         )
 
     return params
@@ -475,10 +489,12 @@ def user(app_with_userprofiles):
     """Create users."""
     with db.session.begin_nested():
         datastore = app_with_userprofiles.extensions['security'].datastore
-        user1 = datastore.create_user(email='info@inveniosoftware.org',
-                                      password='tester', active=True)
-        profile = UserProfile(username='mynick', user=user1)
-        db.session.add(profile)
+        user1 = datastore.create_user(
+            email='info@inveniosoftware.org',
+            password='tester',
+            active=True,
+            username='mynick',
+        )
     db.session.commit()
     return user1
 
@@ -488,10 +504,12 @@ def user_rest(app_rest_with_userprofiles):
     """Create users."""
     with db.session.begin_nested():
         datastore = app_rest_with_userprofiles.extensions['security'].datastore
-        user1 = datastore.create_user(email='info@inveniosoftware.org',
-                                      password='tester', active=True)
-        profile = UserProfile(username='mynick', user=user1)
-        db.session.add(profile)
+        user1 = datastore.create_user(
+            email='info@inveniosoftware.org',
+            password='tester',
+            active=True,
+            username='mynick',
+        )
     db.session.commit()
     return user1
 
@@ -502,8 +520,7 @@ def form_test_data():
     return dict(
                 email='test@tester.com',
                 profile=dict(
-                    full_name='Test Tester',
-                    username='test123',
+                    full_name='Test Tester', username='test123',
                 ),
             )
 
